Index: fpdfsdk/src/fpdfformfill.cpp |
diff --git a/fpdfsdk/src/fpdfformfill.cpp b/fpdfsdk/src/fpdfformfill.cpp |
index 11290eef8bc24386a0ef2bb9342dec0a4cfa458b..a1e807224d69a7e43f060af85b78e9735a7fc2e9 100644 |
--- a/fpdfsdk/src/fpdfformfill.cpp |
+++ b/fpdfsdk/src/fpdfformfill.cpp |
@@ -611,8 +611,8 @@ DLLEXPORT void STDCALL FORM_OnBeforeClosePage(FPDF_PAGE page, |
CPDFSDK_PageView* pPageView = pSDKDoc->GetPageView(pPage, FALSE); |
if (pPageView) { |
pPageView->SetValid(FALSE); |
- // ReMovePageView() takes care of the delete for us. |
- pSDKDoc->ReMovePageView(pPage); |
+ // RemovePageView() takes care of the delete for us. |
+ pSDKDoc->RemovePageView(pPage); |
} |
} |
@@ -634,7 +634,7 @@ DLLEXPORT void STDCALL FORM_DoDocumentAAction(FPDF_FORMHANDLE hHandle, |
if (!pSDKDoc) |
return; |
- CPDF_Document* pDoc = pSDKDoc->GetDocument()->GetPDFDoc(); |
+ CPDF_Document* pDoc = pSDKDoc->GetPDFDocument(); |
CPDF_Dictionary* pDic = pDoc->GetRoot(); |
if (!pDic) |
return; |